# `h2o-secure-store`

[![pypi](https://img.shields.io/pypi/v/h2o-secure-store?style=flat-square)](https://pypi.org/project/h2o-secure-store/)

Python client for [H2O Secure Store](https://docs.h2o.ai/secure-store/).

## Installation

```sh
pip install h2o-secure-store
```

## Usage

Visit the [documentation](https://docs.h2o.ai/secure-store/py/initialization) for more information.